package com.kakao.sdk.link.sample.kakaolink;

import android.app.Activity;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.Toast;

import com.kakao.kakaolink.v2.KakaoLinkResponse;
import com.kakao.kakaolink.v2.KakaoLinkService;
import com.kakao.kakaolink.v2.model.ButtonObject;
import com.kakao.kakaolink.v2.model.ContentObject;
import com.kakao.kakaolink.v2.model.FeedTemplate;
import com.kakao.kakaolink.v2.model.LinkObject;
import com.kakao.kakaolink.v2.model.ListTemplate;
import com.kakao.kakaolink.v2.model.LocationTemplate;
import com.kakao.kakaolink.v2.model.SocialObject;
import com.kakao.network.ErrorResult;
import com.kakao.network.ServerProtocol;
import com.kakao.network.callback.ResponseCallback;
import com.kakao.sdk.link.sample.R;
import com.kakao.util.helper.log.Logger;

import java.util.HashMap;
import java.util.Map;

public class KakaoLink40MainActivity extends Activity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_kakao_link40_main);

        final String[] methods = new String[] {
                getString(R.string.title_default_feed),
                getString(R.string.title_default_list),
                getString(R.string.title_default_location),
                getString(R.string.title_scrap),
                getString(R.string.title_custom_feed),
                };

                ListView listView = (ListView) findViewById(R.id.link40_method_list);
                listView.setAdapter(new ArrayAdapter<String>(this, android.R.layout.simple_list_item_1, methods));
                listView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
                    @Override
                    public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
                        switch (position) {
                            case 0:
                                sendDefaultFeedTemplate();
                                break;
                            case 1:
                                sendDefaultListTemplate();
                                break;
                            case 2:
                                sendDefaultLocationTemplate();
                                break;
                            case 3:
                                sendScrapMessage();
                                break;
                            case 4:
                                sendFeedTemplate();
                                break;
                            default:
                                break;
                }
            }
        });
    }

    private void sendFeedTemplate() {
        String templateId;
        switch (ServerProtocol.DEPLOY_PHASE) {
            case Alpha:
                templateId = "18578";
                break;
            case Sandbox:
                templateId = "222";
                break;
            case Beta:
            case Release:
                templateId = "3135";
                break;
            default:
                return;
        }

        Map<String, String> templateArgs = new HashMap<String, String>();
        templateArgs.put("${title}", "프로방스 자동차 여행");
        templateArgs.put("${description}", "매년 7~8월에 프로방스 발랑솔을 중심으로 라벤더가 만개한다. 이 길을 라벤더로드라고 하며 라벤더와 해바라기 밭이 가득찬 풍경을 어디서나 볼 수 있다.");
        KakaoLinkService.getInstance().sendCustom(this, templateId, templateArgs, new ResponseCallback<KakaoLinkResponse>() {
            @Override
            public void onFailure(ErrorResult errorResult) {
                Logger.e(errorResult.toString());
                Toast.makeText(getApplicationContext(), errorResult.toString(), Toast.LENGTH_LONG).show();
            }

            @Override
            public void onSuccess(KakaoLinkResponse result) {
            }
        });
    }

    private void sendScrapMessage() {
        KakaoLinkService.getInstance().sendScrap(this, "https://dev.kakao.com", new ResponseCallback<KakaoLinkResponse>() {
            @Override
            public void onFailure(ErrorResult errorResult) {
                Logger.e(errorResult.toString());
                Toast.makeText(getApplicationContext(), errorResult.toString(), Toast.LENGTH_LONG).show();
            }

            @Override
            public void onSuccess(KakaoLinkResponse result) {
            }
        });
    }

    private void sendDefaultFeedTemplate() {
        FeedTemplate params = FeedTemplate
                .newBuilder(ContentObject.newBuilder("디저트 사진",
                "http://mud-kage.kakao.co.kr/dn/NTmhS/btqfEUdFAUf/FjKzkZsnoeE4o19klTOVI1/openlink_640x640s.jpg",
                LinkObject.newBuilder().setWebUrl("https://dev.kakao.com")
                        .setMobileWebUrl("https://dev.kakao.com").build())
                .setDescrption("아메리카노, 빵, 케익")
                .build())
                .setSocial(SocialObject.newBuilder().setLikeCount(10).setCommentCount(20)
                        .setSharedCount(30).setViewCount(40).build())
                .addButton(new ButtonObject("웹에서 보기", LinkObject.newBuilder().setWebUrl("'https://dev.kakao.com").setMobileWebUrl("'https://dev.kakao.com").build()))
                .addButton(new ButtonObject("앱에서 보기", LinkObject.newBuilder()
                        .setWebUrl("'https://dev.kakao.com")
                        .setMobileWebUrl("'https://dev.kakao.com")
                        .setAndroidExecutionParams("key1=value1")
                        .setIosExecutionParams("key1=value1")
                        .build()))
                .build();


        KakaoLinkService.getInstance().sendDefault(this, params, new ResponseCallback<KakaoLinkResponse>() {
            @Override
            public void onFailure(ErrorResult errorResult) {
                Logger.e(errorResult.toString());
            }

            @Override
            public void onSuccess(KakaoLinkResponse result) {
            }
        });
    }

    private void sendDefaultListTemplate() {
        ListTemplate params = ListTemplate.newBuilder("WEEKELY MAGAZINE",
                LinkObject.newBuilder()
                        .setWebUrl("https://dev.kakao.com")
                        .setMobileWebUrl("https://dev.kakao.com")
                        .build())
                .addContent(ContentObject.newBuilder("자전거 라이더를 위한 공간",
                        "http://mud-kage.kakao.co.kr/dn/QNvGY/btqfD0SKT9m/k4KUlb1m0dKPHxGV8WbIK1/openlink_640x640s.jpg",
                        LinkObject.newBuilder()
                                .setWebUrl("https://dev.kakao.com")
                                .setMobileWebUrl("https://dev.kakao.com")
                                .build())
                        .setDescrption("매거진")
                        .build())
                .addContent(ContentObject.newBuilder("비쥬얼이 끝내주는 오레오 카푸치노",
                        "http://mud-kage.kakao.co.kr/dn/boVWEm/btqfFGlOpJB/mKsq9z6U2Xpms3NztZgiD1/openlink_640x640s.jpg",
                        LinkObject.newBuilder()
                                .setWebUrl("https://dev.kakao.com")
                                .setMobileWebUrl("https://dev.kakao.com")
                                .build())
                        .setDescrption("매거진")
                        .build())
                .addContent(ContentObject.newBuilder("감성이 가득한 분위기",
                        "http://mud-kage.kakao.co.kr/dn/NTmhS/btqfEUdFAUf/FjKzkZsnoeE4o19klTOVI1/openlink_640x640s.jpg",
                        LinkObject.newBuilder()
                                .setWebUrl("https://dev.kakao.com")
                                .setMobileWebUrl("https://dev.kakao.com")
                                .build())
                        .setDescrption("매거진").build())
                .addButton(new ButtonObject("웹에서 보기", LinkObject.newBuilder()
                        .setMobileWebUrl("https://dev.kakao.com")
                        .setMobileWebUrl("https://dev.kakao.com")
                        .build()))
                .addButton(new ButtonObject("앱에서 보기", LinkObject.newBuilder()
                        .setWebUrl("https://dev.kakao.com")
                        .setMobileWebUrl("https://dev.kakao.com")
                        .setAndroidExecutionParams("key1=value1")
                        .setIosExecutionParams("key1=value1")
                        .build()))
                .build();

        KakaoLinkService.getInstance().sendDefault(this, params, new ResponseCallback<KakaoLinkResponse>() {
            @Override
            public void onFailure(ErrorResult errorResult) {
                Logger.e(errorResult.toString());
            }

            @Override
            public void onHandledFailure(ErrorResult errorResult) {
                Logger.e("onHandledFailure: " + errorResult.getException());
            }

            @Override
            public void onSuccess(KakaoLinkResponse result) {

            }
        });
    }

    private void sendDefaultLocationTemplate() {
        LocationTemplate params = LocationTemplate.newBuilder("성남시 분당구 판교역로 235",
                ContentObject.newBuilder("카카오 판교오피스",
                "http://www.kakaocorp.com/images/logo/og_daumkakao_151001.png",
                    LinkObject.newBuilder()
                            .setWebUrl("https://dev.kakao.com")
                            .setMobileWebUrl("https://dev.kakao.com")
                            .build())
                        .setDescrption("카카오 판교오피스 위치입니다.")
                        .build())
                .setAddressTitle("카카오 판교오피스")
                .build();

        KakaoLinkService.getInstance().sendDefault(this, params, new ResponseCallback<KakaoLinkResponse>() {
            @Override
            public void onFailure(ErrorResult errorResult) {
                Logger.e(errorResult.toString());
            }

            @Override
            public void onSuccess(KakaoLinkResponse result) {

            }
        });
    }
}
