package com.kakao.sdk.link.sample.kakaolink;

import android.app.Activity;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.ListView;
import android.widget.TextView;

import com.kakao.kakaolink.v2.KakaoLinkService;
import com.kakao.network.ErrorResult;
import com.kakao.network.callback.ResponseCallback;
import com.kakao.network.storage.ImageDeleteResponse;
import com.kakao.network.storage.ImageUploadResponse;
import com.kakao.sdk.link.sample.R;
import com.kakao.util.helper.MediaUtils;
import com.kakao.util.helper.log.Logger;

import java.io.File;
import java.io.FileNotFoundException;

public class KakaoLinkImageUploadActivity extends Activity {
    private static final int GALLERY_REQUEST_CODE = 0;
    private String imageUrl;
    private TextView urlTextView;
    private ImageView selectedImageView;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_kakao_link_upload);

        final String[] methods = new String[] {
                getString(R.string.title_image_upload),
                getString(R.string.title_image_delete)
        };

        ListView listView = (ListView) findViewById(R.id.link40_method_list);
        listView.setAdapter(new ArrayAdapter<String>(this, android.R.layout.simple_list_item_1, methods));
        listView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
                switch (position) {
                    case 0:
                        uploadImageForLink();
                        break;
                    case 1:
                        deleteImage();
                        break;
                    default:
                        break;
                }
            }
        });

        urlTextView = (TextView) findViewById(R.id.tv_image_url);
        selectedImageView = (ImageView) findViewById(R.id.selected_image);
    }

    @SuppressWarnings("unused")
    private void uploadImageAfterScrap() {
        KakaoLinkService.getInstance().scrapImage(this, false, "http://www.kakaocorp.com/images/logo/og_daumkakao_151001.png", new ResponseCallback<ImageUploadResponse>() {
            @Override
            public void onFailure(ErrorResult errorResult) {
                Logger.e(errorResult.toString());
            }

            @Override
            public void onSuccess(ImageUploadResponse result) {
                Logger.e(result.getOriginal().getUrl());
            }
        });
    }
    private void uploadImageForLink() {
        Intent intent = new Intent(Intent.ACTION_PICK);
        intent.setType(android.provider.MediaStore.Images.Media.CONTENT_TYPE);
        intent.setData(android.provider.MediaStore.Images.Media.EXTERNAL_CONTENT_URI);
        startActivityForResult(intent, GALLERY_REQUEST_CODE);
    }

    private void deleteImage() {
        if (imageUrl == null) {
            return;
        }
        KakaoLinkService.getInstance().deleteImageWithUrl(KakaoLinkImageUploadActivity.this, imageUrl, new ResponseCallback<ImageDeleteResponse>() {
            @Override
            public void onFailure(ErrorResult errorResult) {
                Logger.e(errorResult.toString());
            }

            @Override
            public void onSuccess(ImageDeleteResponse result) {
                imageUrl = null;
                selectedImageView.setImageURI(null);
                urlTextView.setText("");
            }
        });
    }
    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (requestCode == GALLERY_REQUEST_CODE && resultCode == RESULT_OK) {
            Uri uri = data.getData();
            try {
                selectedImageView.setImageURI(uri);
                File imageFile = new File(MediaUtils.getImageFilePathFromUri(uri, this));

                KakaoLinkService.getInstance().uploadImage(this, false, imageFile, new ResponseCallback<ImageUploadResponse>() {
                    @Override
                    public void onFailure(ErrorResult errorResult) {
                        Logger.e(errorResult.toString());
                    }

                    @Override
                    public void onSuccess(ImageUploadResponse result) {
                        imageUrl = result.getOriginal().getUrl();
                        urlTextView.setText(imageUrl);
                    }
                });
            } catch (FileNotFoundException e) {
                Logger.e(e.toString());
            }

        }
    }
}
