package com.kakao.s2;

import com.kakao.network.NetworkTask;
import com.kakao.network.RequestConfiguration;
import com.kakao.network.response.ResponseData;
import com.kakao.test.common.KakaoPowerMockTestCase;

import org.junit.Before;
import org.junit.Test;
import org.powermock.core.classloader.annotations.PrepareForTest;

import java.util.Date;
import java.util.LinkedList;
import java.util.List;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.fail;
import static org.powermock.api.support.membermodification.MemberMatcher.method;
import static org.powermock.api.support.membermodification.MemberModifier.stub;

/**
 * @author kevin.kang
 * Created by kevin.kang on 2016. 8. 24..
 */

@PrepareForTest({ NetworkTask.class })
public class S2ApiTest extends KakaoPowerMockTestCase {
    private List<Event> leafEvents;
    private RequestConfiguration configuration =  new RequestConfiguration("sample_app_key", "sample_ka_header", "sample_key_hash", "sample_extras", "sample_app_ver", "sample_package_name");

    @Before
    public void setup() {
        super.setUp();

        final String to = "http://www.kakaocorp.com";
        final String action = "click";

        leafEvents = new LinkedList<>();
        leafEvents.add(new Event.Builder().setTo(to).setAction(action).setTimestamp(new Date().getTime() + 1000).build());
        leafEvents.add(new Event.Builder().setTo(to).setAction(action).setTimestamp(new Date().getTime() + 2000).build());


    }

    @Test
    public void testRequestLoggingEvents() throws Exception {
        stub(method(NetworkTask.class, "request")).toReturn(new ResponseData(200, "{count:5}".getBytes()));
        EventsLogResponse response = S2Api.requestPublishingEvents(configuration, null, leafEvents);
        assertNotNull(response);
        assertEquals(5, response.getSuccessCount());
    }

    @Test
    @SuppressWarnings("unused")
    public void testRequestLoggingEventsWithException() throws Exception {
        stub(method(NetworkTask.class, "request")).toThrow(new Exception("request exception"));
        try {
            EventsLogResponse response = S2Api.requestPublishingEvents(configuration, null, leafEvents);
            fail("Exception should have been thrown...");
        } catch (Exception e) {
            assertEquals(e.getMessage(), "request exception");
        }


    }
}
